# Pytorch CML
Collaborative Metric Learning implemented by pytorch

# Usage
1. Set model, optimizer, loss, sampler and evaluator.
2. Input these to trainer.
3. Run fit method.

See examples for detail.